@@ -15,7 +15,7 @@ import sys
 from distutils.version import LooseVersion
 
 from . import exc
-from ._compat import console_to_str, str_from_console, MutableMapping
+from ._compat import MutableMapping, console_to_str, str_from_console
 
 logger = logging.getLogger(__name__)
 
@@ -205,11 +205,7 @@ class tmux_cmd(object):
             self.process = subprocess.Popen(
                 cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE
             )
-            self.process.wait()
-            stdout = self.process.stdout.read()
-            self.process.stdout.close()
-            stderr = self.process.stderr.read()
-            self.process.stderr.close()
+            stdout, stderr = self.process.communicate()
             returncode = self.process.returncode
         except Exception as e:
             logger.error('Exception for %s: \n%s' % (subprocess.list2cmdline(cmd), e))
@@ -233,7 +229,7 @@ class tmux_cmd(object):
 
 class TmuxMappingObject(MutableMapping):
 
-    """Base: :py:class:`MutableMapping`.
+    r"""Base: :py:class:`MutableMapping`.
 
     Convenience container. Base class for :class:`Pane`, :class:`Window`,
     :class:`Session` and :class:`Server`.
@@ -668,3 +664,16 @@ def handle_option_error(error):
         raise exc.AmbiguousOption(error)
     else:
         raise exc.OptionError(error)  # Raise generic option error
+
+
+def get_libtmux_version():
+    """Return libtmux version is a PEP386 compliant format.
+
+    Returns
+    -------
+    distutils.version.LooseVersion
+        libtmux version
+    """
+    from libtmux.__about__ import __version__
+
+    return LooseVersion(__version__)
